### Name: rdaTest
### Title: Canonical redundancy analysis (RDA)
### Aliases: rdaTest probFrda FractionBySpecies vif rdaTest spiders.spe
###   spiders.env Table.11.3
### Keywords: multivariate

### ** Examples

## Analysis of Table 11.3 of Legendre and Legendre (1998, p. 590)  
data(Table.11.3)
Y = Table.11.3[,1:6]
X = Table.11.3[,7:10]
result = rdaTest(Y, X, test.F=TRUE, nperm=999)
plot(result, graph.type="Z")

## Run rdaTest in such a way that it prints no output to the R console
resuls <- rdaTest(Y, X, test.F=TRUE, nperm=999, silent=TRUE) 

## Reverse orientation of abscissa (parameter xax) in the plot
plot(result, xax=-1, yax=2, mul.spe=0.90, mul.env=0.70, mul.text=0.10,
scaling=1, graph.type="F", mai.perc=0.15, pos.sites=3) 

## Draw confidence ellipses around groups of points, spider data 
## (Aart and Smeenk-Enserink, 1975)
data(spiders.spe)
data(spiders.env) 
# Hellinger transformation of the species abundance data prior to RDA
library(vegan)
spiders.hel = decostand(spiders.spe, "hellinger")
result.spiders = rdaTest(spiders.hel, spiders.env, test.F=TRUE, nperm=999)
# Vector vec divides the sites into three a priori groups
vec = c(2,1,2,1,1,3,1,3,2,2,2,2,1,3,3,3,3,3,3,3,3,2,2,2,3,2,2,2)
plot(result.spiders, graph.type="Z", ell=vec, lty.ell=3, pos.sites=4,
mar.perc=0.15)

## Plot the sites and environmental variables, but not the species
plot(result.spiders, graph.type="Z", plot.spe=FALSE, ell=vec, lty.ell=3,
pos.sites=4, mar.perc=0.15)

## See graphical options for triplots in this-is-escaped-code{.

## Test significance of individual canonical axes. See this-is-escaped-codenormal-bracket95bracket-normal
out = test.axes(Y, X, nperm=999)
out$test.axes

out = test.axes(spiders.hel, spiders.env, nperm=499)
out$test.axes

out = test.axes(spiders.hel, spiders.env[,-1], spiders.env[,1], nperm=499)
out$test.axes



